# ZhongLP

A Zhongwen (Chinese) Language Processing Package.


## Description

```
from ZhongLP.segmenter import Segmenter
from ZhongLP import zh_utils

```


## Installation

From PyPI distribution system:

```
pip install ZhongLP
```


Or from the code:

```
git clone https://github.com/Li-Ming-Fan/ZhongLP
cd ZhongLP
make clean install
```


Or just incorporate the directory ZhongLP/ to your project.



## Usage

For usage of this package, please refer to the demo, or the repositories:

TODO


</br>

## Acknowledgment

We thank the authors and contributors of jieba, HanLP and other Packages for Chinese Language Processing.


